==> clash-ghc-1.8.2-86.1-loong64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clash-ghc
version:              1.8.2
visibility:           public
id:                   clash-ghc-1.8.2-D3MI9DnxIBI7prI5lsq11v
key:                  clash-ghc-1.8.2-D3MI9DnxIBI7prI5lsq11v
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  9a79296cf65b90d3a4ad9a80efff0969
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.Leak Clash.GHCi.UI Clash.GHCi.UI.Info
    Clash.GHCi.UI.Monad Clash.GHC.ClashFlags Clash.GHC.GHC2Core
    Clash.GHC.LoadInterfaceFiles Clash.GHC.Util Data.Text.Extra
    Paths_clash_ghc Clash.GHCi.Util Clash.GHCi.UI.Tags

import-dirs:          /usr/lib/ghc-9.6.6/site-local/clash-ghc-1.8.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/clash-ghc-1.8.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/clash-ghc-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/clash-ghc
hs-libraries:         HSclash-ghc-1.8.2-D3MI9DnxIBI7prI5lsq11v
depends:
    Cabal-3.10.3.0 array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    clash-lib-1.8.2-3l0rHcAqO3B17VGNN3pwcO
    clash-prelude-1.8.2-AjLxC8X9VplIMnC0qrDm33 containers-0.6.7
    data-binary-ieee754-0.4.4-4UW07Uhzyok6gyNDRTrrKK deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy filepath-1.4.300.1 ghc-9.6.6
    ghc-bignum-1.3 ghc-boot-9.6.6 ghc-prim-0.10.0
    ghc-typelits-extra-0.4.8-G3ejHAhtPGCEC46XOHGVud
    ghc-typelits-knownnat-0.7.12-2iaFRapo9gXUXHFFZyqWd
    ghc-typelits-natnormalise-0.7.12-ID8plq7KcvWHB1mPTHwLeK ghci-9.6.6
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z haskeline-0.8.2.1
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM mtl-2.3.1
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ process-1.6.19.0
    reflection-2.1.9-LtSX5qahOBWBJVCTiw5gqi
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    string-interpolate-0.3.4.0-8Ylcj5G5syjBAwauWVRpr1
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 uniplate-1.6.13-3WatGBC3kLsu5Mf9WJ1JN
    unix-2.8.4.0 unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> clash-ghc-1.8.2-87-loong64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clash-ghc
version:              1.8.2
visibility:           public
id:                   clash-ghc-1.8.2-GnJA9Ij0oRwJpGNjnufbRC
key:                  clash-ghc-1.8.2-GnJA9Ij0oRwJpGNjnufbRC
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  006e80c83fd900fcb639e58a3d0dc5d1
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.Leak Clash.GHCi.UI Clash.GHCi.UI.Info
    Clash.GHCi.UI.Monad Clash.GHC.ClashFlags Clash.GHC.GHC2Core
    Clash.GHC.LoadInterfaceFiles Clash.GHC.Util Data.Text.Extra
    Paths_clash_ghc Clash.GHCi.Util Clash.GHCi.UI.Tags

import-dirs:          /usr/lib/ghc-9.6.6/site-local/clash-ghc-1.8.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/clash-ghc-1.8.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/clash-ghc-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/clash-ghc
hs-libraries:         HSclash-ghc-1.8.2-GnJA9Ij0oRwJpGNjnufbRC
depends:
    Cabal-3.10.3.0 array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    clash-lib-1.8.2-BSJ2aHMHCxK17pHfEPddyo
    clash-prelude-1.8.2-EqmKuTkNb2FAELIfUNplXY containers-0.6.7
    data-binary-ieee754-0.4.4-4UW07Uhzyok6gyNDRTrrKK deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb filepath-1.4.300.1 ghc-9.6.6
    ghc-bignum-1.3 ghc-boot-9.6.6 ghc-prim-0.10.0
    ghc-typelits-extra-0.4.8-12v9LxbhYUPKbwDLTuNUI
    ghc-typelits-knownnat-0.7.12-8d5kSKxBjaM8cKbBLtlwFV
    ghc-typelits-natnormalise-0.7.12-4A61GQNMhINCZAlCrgN5bt ghci-9.6.6
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD haskeline-0.8.2.1
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB mtl-2.3.1
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi process-1.6.19.0
    reflection-2.1.9-8Q7I5njAXv0HxAP0gvhFsJ
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    string-interpolate-0.3.4.0-40hVGApsbsSBa1DsDPkXGs
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 uniplate-1.6.13-KGH5CSn0bIt6TRjVfDPPFU
    unix-2.8.4.0 unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
